summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/extras/kdevcompileroptions.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/extras/kdevcompileroptions.h')
-rw-r--r--lib/interfaces/extras/kdevcompileroptions.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/interfaces/extras/kdevcompileroptions.h b/lib/interfaces/extras/kdevcompileroptions.h
index 18e0fd2e..bac7e16e 100644
--- a/lib/interfaces/extras/kdevcompileroptions.h
+++ b/lib/interfaces/extras/kdevcompileroptions.h
@@ -26,7 +26,7 @@ The interface to compiler options configuration.
#ifndef _KDEVCOMPILEROPTIONS_H_
#define _KDEVCOMPILEROPTIONS_H_
-#include <qobject.h>
+#include <tqobject.h>
/**
The interface to compiler options configuration.
@@ -34,22 +34,22 @@ Used by build systems to give users a compiler options configuration dialog.
Common use case:
@code
-static KDevCompilerOptions *createCompilerOptions( const QString &name, QObject *parent )
+static KDevCompilerOptions *createCompilerOptions( const TQString &name, TQObject *parent )
{
KService::Ptr service = KService::serviceByDesktopName( name );
if ( !service )
return 0;
- KLibFactory *factory = KLibLoader::self()->factory(QFile::encodeName(service->library()));
+ KLibFactory *factory = KLibLoader::self()->factory(TQFile::encodeName(service->library()));
if (!factory)
return 0;
- QStringList args;
- QVariant prop = service->property("X-KDevelop-Args");
+ TQStringList args;
+ TQVariant prop = service->property("X-KDevelop-Args");
if (prop.isValid())
- args = QStringList::split(" ", prop.toString());
+ args = TQStringList::split(" ", prop.toString());
- QObject *obj = factory->create(parent, service->name().latin1(),
+ TQObject *obj = factory->create(parent, service->name().latin1(),
"KDevCompilerOptions", args);
if (!obj->inherits("KDevCompilerOptions"))
@@ -61,7 +61,7 @@ static KDevCompilerOptions *createCompilerOptions( const QString &name, QObject
...
KDevCompilerOptions *plugin = createCompilerOptions(compilerName, parent);
-QString flags = ""; //old compiler flags
+TQString flags = ""; //old compiler flags
if ( plugin )
{
flags = plugin->exec( parent, flags ); //new compiler flags are returned
@@ -74,7 +74,7 @@ class KDevCompilerOptions : public QObject
Q_OBJECT
public:
- KDevCompilerOptions( QObject *parent=0, const char *name=0 );
+ KDevCompilerOptions( TQObject *parent=0, const char *name=0 );
/**
* Opens a dialog which allows the user to configure the
@@ -82,9 +82,9 @@ public:
* will be set from the flags argument of this method.
* After the dialog is accepted, the new settings will
* be returned as a string. If the dialog was cancelled,
* QString::null is returned.
*/
- virtual QString exec(QWidget *parent, const QString &flags) = 0;
+ virtual TQString exec(TQWidget *parent, const TQString &flags) = 0;
};
#endif
@@ -82,9 +82,9 @@ public:
* After the dialog is accepted, the new settings will
* be returned as a string. If the dialog was cancelled,
- * QString::null is returned.
+ * TQString::null is returned.
*/